@@ -603,7 +603,7 @@ class ChannelViewSet(viewsets.ModelViewSet):
                      'child_channel': Channel.objects.get(**kwargs).id,
                      'hub': Channel.objects.get(**kwargs).hub.id})
         hardware_ios = Channel.objects.get(**kwargs).hardwareio_set.all()
-        channel_stats = Channel.objects.get(**kwargs).channellstats_set.all()
+        channel_stats = Channel.objects.get(**kwargs).channelstats_set.all()
 
         channel = Channel.objects.get(**kwargs)
 
